/*
 * Java
 *
 * Copyright 2018-2019 MicroEJ Corp. All rights reserved.
 * MicroEJ Corp. PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
 */
package com.microej.wadapps.connectivity;

import android.net.ConnectivityManager.NetworkCallback;
import android.net.Network;
import android.net.NetworkCapabilities;

/**
 * Wrap a {@link NetworkCallback}, forward its callback to the feature.
 */
public class KernelNetworkCallback extends NetworkCallback {

	private final NetworkCallback featureCallback;

	/**
	 * Instantiates a {@link KernelNetworkCallback}.
	 *
	 * @param featureCallback
	 *            the feature to call.
	 */
	public KernelNetworkCallback(NetworkCallback featureCallback) {
		this.featureCallback = featureCallback;
	}

	/**
	 * @see android.net.ConnectivityManager.NetworkCallback#onAvailable(android.net.Network)
	 */
	@Override
	public void onAvailable(Network network) {
		this.featureCallback.onAvailable(network);
	}

	/**
	 * @see android.net.ConnectivityManager.NetworkCallback#onCapabilitiesChanged(android.net.Network,
	 *      android.net.NetworkCapabilities)
	 */
	@Override
	public void onCapabilitiesChanged(Network network, NetworkCapabilities networkCapabilities) {
		this.featureCallback.onCapabilitiesChanged(network, networkCapabilities);
	}

	/**
	 * @see android.net.ConnectivityManager.NetworkCallback#onLost(android.net.Network)
	 */
	@Override
	public void onLost(Network network) {
		this.featureCallback.onLost(network);
	}

	/**
	 * Gets the featureCallback.
	 *
	 * @return the featureCallback.
	 */
	public NetworkCallback getFeatureCallback() {
		return this.featureCallback;
	}
}
