/*
 * Java
 *
 * Copyright 2015-2017 IS2T. All rights reserved.
 * IS2T PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
 */
package com.microej.wadapps.management.util;

import java.util.ArrayList;
import java.util.Collection;

import ej.components.dependencyinjection.ServiceLoaderFactory;
import ej.observable.Observable;
import ej.wadapps.admin.Application;
import ej.wadapps.admin.Application.State;
import ej.wadapps.admin.ApplicationLifecycleListener;
import ej.wadapps.admin.ApplicationsManager;
import ej.wadapps.app.Activity;
import ej.wadapps.management.ActivitiesList;

/**
 * Default {@link ActivitiesList} implementation.
 */
public class ActivitiesListImpl extends Observable implements ActivitiesList, ApplicationLifecycleListener {

	private final Collection<Activity> activities;

	/**
	 * Default constructor.
	 */
	public ActivitiesListImpl() {
		this.activities = new ArrayList<>();
		ServiceLoaderFactory.getServiceLoader().getService(ApplicationsManager.class)
				.addApplicationLifecycleListener(this);
	}

	@Override
	public void add(Activity activity) {
		synchronized (this.activities) {
			this.activities.add(activity);
		}
		setChanged();
		notifyObservers();
	}

	@Override
	public void remove(Activity activity) {
		synchronized (this.activities) {
			this.activities.remove(activity);
		}
		setChanged();
		notifyObservers();
	}

	@Override
	public Activity[] getActivities() {
		synchronized (this.activities) {
			return this.activities.toArray(new Activity[this.activities.size()]);
		}
	}

	@Override
	public void stateChanged(Application application) {
		if (application.getState() == State.INSTALLED) {
			boolean cleaned;
			synchronized (this.activities) {
				cleaned = ArrayUtils.cleanup(this.activities);
			}
			if (cleaned) {
				setChanged();
				notifyObservers();
			}
		}
	}
}
