/*
 * Java
 *
 * Copyright 2014-2019 MicroEJ Corp. All rights reserved.
 * This library is provided in source code for use, modification and test, subject to license terms.
 * Any modification of the source code will break MicroEJ Corp. warranties on the whole library.
 */
package ej.basedriver.impl;

import java.util.Collection;
import java.util.HashMap;
import java.util.Map;
import java.util.Set;

import ej.ecom.Device;
import ej.ecom.HardwareDescriptor;

/**
 * An Hardware descriptor based on a [names,values] {@link Map}.
 * @param <D>
 */
public class PropertiesDescriptor<D extends Device> implements HardwareDescriptor<D> {

	private Map<String, String> properties;
	private String name;

	/**
	 * Create an hardware descriptor with an empty set of empty properties
	 * @param name the {@link HardwareDescriptor} name
	 */
	public PropertiesDescriptor(String name){
		this(name, new HashMap<String,String>());
	}

	/**
	 * Create an hardware descriptor with set of properties
	 * @param name the {@link HardwareDescriptor} name
	 * @param properties the map of [names,values]
	 */
	public PropertiesDescriptor(String name, Map<String, String> properties){
		this.name = name;
		this.properties = properties;
	}

	@Override
	public String getName() {
		return name;
	}

	/**
	 * Sets the name.
	 * @param name the name to set.
	 */
	public void setName(String name) {
		this.name = name;
	}

	@Override
	public String getProperty(String propertyName) {
		return properties.get(propertyName);
	}

	@Override
	public String[] getPropertyNames() {
		Set<String> keys = properties.keySet();
		return keys.toArray(new String[keys.size()]);
	}

	@Override
	public String[] getPropertyValues() {
		Collection<String> values = properties.values();
		return values.toArray(new String[values.size()]);
	}

	/**
	 * Sets a property. If the property name already exists, its previous value is overrided.
	 * @param name the property name
	 * @param value the property value
	 */
	public void setProperty(String name, String value) {
		this.properties.put(name, value);
	}
}
