/*
 * Java
 *
 * Copyright 2014-2019 MicroEJ Corp. All rights reserved.
 * This library is provided in source code for use, modification and test, subject to license terms.
 * Any modification of the source code will break MicroEJ Corp. warranties on the whole library.
 */
package ej.basedriver.zwave.frame;

import java.io.IOException;

import ej.basedriver.Controller;
import ej.basedriver.zwave.Session;
import ej.basedriver.zwave.ZwaveController;
import ej.basedriver.zwave.ZwaveProtocol;

public class RemoveNodeToNetwork extends RequestFrame {

	public static RequestFrame exclusionStart (RequestFrameListener listener) {
		RemoveNodeToNetwork frame = new RemoveNodeToNetwork(listener, Session.EXCLUSION);
		frame.addParameter(ZwaveProtocol.REMOVE_NODE_ANY);
		frame.addParameter((byte) 0xFF);
		return frame;
	}

	public static RequestFrame exclusionStop(RequestFrameListener listener) {
		RemoveNodeToNetwork frame = new RemoveNodeToNetwork(listener, Session.NONE);
		frame.addParameter(ZwaveProtocol.REMOVE_NODE_STOP);
		return frame;
	}

	private final Session session;

	/**
	 * @param listener
	 * @param functionID
	 */
	private RemoveNodeToNetwork(RequestFrameListener listener, Session session) {
		super(listener, ZwaveProtocol.FUNC_ID_ZW_REMOVE_NODE_FROM_NETWORK, 2);
		this.session = session;
	}

	@Override
	public Session getSession() {
		return session;
	}

	@Override
	public void handleRequest(ZwaveController controller, DataFrame dataFrame)
			throws IOException {
		byte [] bytes =  dataFrame.getBytes();
		byte status = bytes[5];
		switch (status) {
		case ZwaveProtocol.REMOVE_NODE_STATUS_LEARN_READY:
			Session.LEARN_READY.close();
			controller.setState(Controller.EXCLUSION);
			break;
		case ZwaveProtocol.REMOVE_NODE_STATUS_NODE_FOUND:
			break;
		case ZwaveProtocol.REMOVE_NODE_STATUS_REMOVING_CONTROLLER:
			Session.NODE_FOUND.close();
			controller.removeNode(dataFrame.getBytes()[6]);
			break;
		case ZwaveProtocol.REMOVE_NODE_STATUS_REMOVING_SLAVE:
			Session.NODE_FOUND.close();
			controller.removeNode(dataFrame.getBytes()[6]);
			break;
		case ZwaveProtocol.REMOVE_NODE_STATUS_DONE:
			Session.REMOVE_NODE.close();
			break;
		case ZwaveProtocol.REMOVE_NODE_STATUS_FAILED:
			Session.REMOVE_NODE.close();
			break;
		}
	}
}
