/*
 * Java
 *
 * Copyright 2015-2018 IS2T. All rights reserved.
 * IS2T PROPRIETARY/CONFIDENTIAL. Use is subject to license terms.
 */
package ej.components.dependencyinjection;

import java.io.IOException;
import java.io.InputStream;
import java.util.Properties;

/**
 * Service loader that retrieves services implementations from a property file.
 *
 * @see AbstractServiceLoader
 */
public class FilePropertiesServiceLoader extends AbstractServiceLoader {

	private final String file;

	/**
	 * Creates a new file properties service loader.
	 *
	 * @param path
	 *            the properties file path.
	 */
	public FilePropertiesServiceLoader(String path) {
		this.file = path;
	}

	@Override
	protected String getImplementationName(String serviceName) {
        Properties properties = new Properties();
			try (InputStream is = FilePropertiesServiceLoader.class.getResourceAsStream(this.file)) {
            properties.load(is);
			} catch (IOException | NullPointerException e) {
				// cannot read file
			}
        return properties.getProperty(serviceName);
	}
}
