/*
 * Java
 *
 * Copyright 2016-2019 MicroEJ Corp. All rights reserved.
 * This library is provided in source code for use, modification and test, subject to license terms.
 * Any modification of the source code will break MicroEJ Corp. warranties on the whole library.
 */
package ej.data.json;

import java.io.InputStream;

import ej.data.AbstractDataReader;
import ej.data.DataReader;
import ej.json.JSONReader;

/**
 * Implementation of a {@link DataReader} for a JSON stream.
 */
public class DataReaderJSON extends AbstractDataReader {


	private static final char ARRAY_START 	= '[';
	private static final char ARRAY_END 	= ']';
	private static final char MAP_START 	= '{';
	private static final char MAP_END 		= '}';

	JSONReader reader;

	/**
	 * Creates a new {@link DataReader} on the given {@link InputStream}.
	 * @param is the {@link InputStream} from which the JSON structured data is read.
	 */
	public DataReaderJSON(InputStream is) {
		reader = new JSONReader(is);
	}

	@Override
	public boolean hasMoreElements0() throws Throwable {
		char c = reader.peek();
		if(c == MAP_END || c == ARRAY_END || c == 0){
			return false;
		}
		else{
			return true;
		}
	}


	@Override
	public boolean readBooleanValue0() throws Throwable{
		return (Boolean)reader.nextValue();
	}

	@Override
	public int readIntValue0() throws Throwable{
		return (Integer)reader.nextValue();
	}

	@Override
	public long readLongValue0() throws Throwable{
		Object o = reader.nextValue();
		return ((Number)o).longValue();
	}

	@Override
	public String readStringValue0() throws Throwable{
		return (String)reader.nextValue();
	}

	@Override
	public double readDoubleValue0() throws Throwable{
		Object o = reader.nextValue();
		return ((Number)o).doubleValue();
	}

	@Override
	public String readStringKey0() throws Throwable{
		return reader.nextKey();
	}

	@Override
	public int readIntKey0() throws Throwable{
		return Integer.parseInt(readStringKey0());
	}

	@Override
	public void readArrayValueStart0() throws Throwable{
		reader.arrayStart();
	}

	@Override
	public void readArrayValueEnd0() throws Throwable{
		reader.arrayEnd();
	}

	@Override
	public void readMapValueStart0() throws Throwable{
		reader.mapStart();
	}

	@Override
	public void readMapValueEnd0() throws Throwable{
		reader.mapEnd();
	}

	@Override
	public void skipValue0() throws Throwable {
		char startChar = reader.peek();
		if(startChar == ARRAY_START){
			readArrayValueStart0();
			while(hasMoreElements0()){
				skipValue0();
			}
			readArrayValueEnd0();
		}
		else if(startChar == MAP_START){
			readMapValueStart0();
			while(hasMoreElements0()){
				readStringKey0();
				skipValue0();
			}
			readMapValueEnd0();
		}
		else{
			Object o = reader.nextValue();
			if(o == null){
				throw new AssertionError();
			}
		}

	}
}
