/*
 * Java
 *
 * Copyright 2016-2019 MicroEJ Corp. All rights reserved.
 * This library is provided in source code for use, modification and test, subject to license terms.
 * Any modification of the source code will break MicroEJ Corp. warranties on the whole library.
 */
package ej.data.json;

import java.io.OutputStream;

import ej.data.AbstractDataWriter;
import ej.data.DataWriter;
import ej.json.JSONWriter;

/**
 * Implementation of a {@link DataWriter} for a JSON stream.
 */
public class DataWriterJSON extends AbstractDataWriter{

	JSONWriter encoder;

	/**
	 * Creates a new {@link DataWriter} on the given {@link OutputStream}.<p>
	 * The {@link OutputStream} is automatically flushed when the data has been fully written.
	 * @param os the {@link OutputStream} to which the JSON structured data is written.
	 */
	public DataWriterJSON(OutputStream os){
		super(os);
		encoder = new JSONWriter(os);
	}

	@Override
	public void writeBooleanValue0(boolean value) throws Throwable{
		encoder.value(value);
	}

	@Override
	public void writeIntValue0(int value) throws Throwable{
		encoder.value(value);
	}

	@Override
	public void writeLongValue0(long value) throws Throwable{
		encoder.value(value);
	}

	@Override
	public void writeStringValue0(String value) throws Throwable{
		encoder.value(value);
	}

	@Override
	public void writeDoubleValue0(double value) throws Throwable{
		encoder.value(value);
	}

	@Override
	public void writeStringKey0(String key) throws Throwable{
		encoder.key(key);
	}

	@Override
	public void writeIntKey0(int key) throws Throwable{
		encoder.key(String.valueOf(key));
	}

	@Override
	public void writeArrayValueStart0() throws Throwable{
		encoder.array();
	}

	@Override
	public void writeArrayValueEnd0() throws Throwable{
		encoder.endArray();
	}

	@Override
	public void writeMapValueStart0() throws Throwable{
		encoder.object();
	}

	@Override
	public void writeMapValueEnd0() throws Throwable{
		encoder.endObject();
	}
}
