/*
 * Java
 *
 * Copyright 2017-2019 MicroEJ Corp. All rights reserved.
 * This library is provided in source code for use, modification and test, subject to license terms.
 * Any modification of the source code will break MicroEJ Corp. warranties on the whole library.
 */
package ej.data.pubsub.paho;

import java.io.InputStream;
import java.io.OutputStream;

import org.eclipse.paho.client.mqttv3.MqttMessage;

import ej.data.DataReader;
import ej.data.DataWriter;
import ej.data.pubsub.MqttContext;
import ej.data.pubsub.MqttListener;

/**
 * Configuration class used by {@link PahoMqttAgent} to create{@link DataReader} and {@link DataWriter} for
 * specific MQTT topics, get the topics and notify errors.
 */
public interface MqttAgentConfiguration {

	/**
	 * Creates a {@link DataWriter} for the given topic. The created {@link DataWriter}
	 * must use the given {@link OutputStream} to write the data.
	 * @param os the {@link OutputStream} used by the created {@link DataWriter}.
	 * @param topic the MQTT topic.
	 * @return a {@link DataWriter} for the MQTT topic.
	 */
	public DataWriter newDataWriter(OutputStream os, String topic);

	/**
	 * Creates a {@link DataReader} for the given topic. The created {@link DataReader}
	 * must use the given {@link InputStream} to read the data.
	 * @param is the {@link InputStream} used by the created {@link DataReader}.
	 * @param topic the MQTT topic.
	 * @return a {@link DataReader} for the MQTT topic.
	 */
	public DataReader newDataReader(InputStream is, String topic);

	/**
	 * Returns the topic prefix to use to publish data shared with other accounts.
	 * The returned {@link String} ends with a <code>'/'</code> if it is not empty.
	 * @return an MQTT topic prefix.
	 */
	public String getSharedTopicPrefix();

	/**
	 * Returns the topic prefix to use to publish data sandboxed within the current account.
	 * The returned {@link String} ends with a <code>'/'</code> if it is not empty.
	 * @return an MQTT topic prefix.
	 */
	public String getLocalTopicPrefix();

	/**
	 * Method called when an error occurs while calling a listener {@link MqttListener#messageReceived(String, DataReader)}.
	 * @param message the received MQTT message.
	 * @param topic name of the topic on the message was published to.
	 * @param context {@link MqttContext} that owns the listener that generates the error.
	 * @param t the thrown error.
	 */
	public void errorOnMessageReceivedCallback(Throwable t, PahoMqttContext context, String topic, MqttMessage message);

}
