/*
 * Java
 *
 * Copyright 2015-2019 MicroEJ Corp. All rights reserved.
 * This library is provided in source code for use, modification and test, subject to license terms.
 * Any modification of the source code will break MicroEJ Corp. warranties on the whole library.
 */
package ej.style;

import ej.annotation.NonNull;

/**
 * Represents a selector.
 */
public interface Selector {

	/**
	 * Checks whether or not the given element fits this selector.
	 *
	 * @param element
	 *            the element to test.
	 * @return <code>true</code> if the given element fit this selector, <code>false</code> otherwise.
	 */
	boolean fit(@NonNull Element element);

	/**
	 * Gets the selector specificity.
	 * <p>
	 * See CSS for more information about calculating a selector's specificity.
	 *
	 * @return selector's specificity.
	 */
	int getSpecificity();

}
