/*
 * Java
 *
 * Copyright 2015-2019 MicroEJ Corp. All rights reserved.
 * This library is provided in source code for use, modification and test, subject to license terms.
 * Any modification of the source code will break MicroEJ Corp. warranties on the whole library.
 */
package ej.style.font.filter;

import java.util.ArrayList;
import java.util.List;

import ej.microui.display.Font;

/**
 * Provides some font facilities.
 */
public class FontFilterHelper {

	// Prevents initialization.
	private FontFilterHelper() {
	}

	/**
	 * Filters the given fonts from the given filter.
	 *
	 * @param fontFilter
	 *            the filter to use.
	 * @param fonts
	 *            the fonts to filter.
	 * @return the fonts accepted by the filter.
	 */
	public static Font[] filter(Filter<Font> fontFilter, Font[] fonts) {
		List<Font> fontsAccepted = new ArrayList<>(1);

		for (Font font : fonts) {
			if (fontFilter.accept(font)) {
				fontsAccepted.add(font);
			}
		}

		return fontsAccepted.toArray(new Font[fontsAccepted.size()]);
	}
}
