/*
 * Java
 *
 * Copyright 2016-2019 MicroEJ Corp. All rights reserved.
 * This library is provided in source code for use, modification and test, subject to license terms.
 * Any modification of the source code will break MicroEJ Corp. warranties on the whole library.
 */
package ej.style.selector;

import ej.annotation.Nullable;
import ej.style.Element;
import ej.style.Selector;

/**
 * An universal selector selects all elements.
 * <p>
 * Equivalent to <code>*</code> selector in CSS. Its specificity is (0,0,0,0).
 *
 * @see SpecificityHelper
 */
public class UniversalSelector implements Selector {

	/**
	 * Universal selector singleton to avoid creating several ones.
	 */
	public static final UniversalSelector UNIVERSAL_SELECTOR = new UniversalSelector();

	/**
	 * Creates an universal selector.
	 */
	public UniversalSelector() {
	}

	@Override
	public boolean fit(Element element) {
		return true;
	}

	@Override
	public int getSpecificity() {
		return SpecificityHelper.getSpecificity(0, 0, 0, 0);
	}

	@Override
	public int hashCode() {
		return 0;
	}

	@Override
	public boolean equals(@Nullable Object obj) {
		return (obj instanceof UniversalSelector);
	}

}
