/*
 * Java
 *
 * Copyright 2015-2019 MicroEJ Corp. All rights reserved.
 * This library is provided in source code for use, modification and test, subject to license terms.
 * Any modification of the source code will break MicroEJ Corp. warranties on the whole library.
 */
package ej.style.text;

import ej.microui.display.Font;
import ej.microui.display.GraphicsContext;
import ej.style.container.Rectangle;

/**
 * A text manager is responsible for the rendering of text content.
 */
public interface TextManager {

	/**
	 * Computes a text size for a font.
	 *
	 * @param text
	 *            the text.
	 * @param font
	 *            the font.
	 * @param availableSize
	 *            the available size.
	 * @return the text size with the given font.
	 */
	Rectangle computeContentSize(String text, Font font, Rectangle availableSize);

	/**
	 * Draws text on a graphics context.
	 * <p>
	 * The given graphics context is translated and clipped according to the given area.
	 *
	 * @param g
	 *            the graphics context to draw the text on.
	 * @param text
	 *            the text to render.
	 * @param font
	 *            the font to use.
	 * @param color
	 *            the color to use.
	 * @param area
	 *            the text area.
	 * @param alignment
	 *            the text alignment.
	 */
	void drawText(GraphicsContext g, String text, Font font, int color, Rectangle area, int alignment);

	/**
	 * Gets the index of the character at a location.
	 *
	 * @param x
	 *            the x coordinate of the location to search the character at.
	 * @param y
	 *            the x coordinate of the location to search the character at.
	 * @param text
	 *            the text to search the character in.
	 * @param font
	 *            the font.
	 * @param area
	 *            the text area.
	 * @param alignment
	 *            the text alignment.
	 * @return the index of the character at the given location.
	 */
	int getIndex(int x, int y, String text, Font font, Rectangle area, int alignment);

	/**
	 * Gets the bounds surrounding a part of the text.
	 *
	 * @param startIndex
	 *            the sub text start index.
	 * @param endIndex
	 *            the sub text end index.
	 * @param text
	 *            the text.
	 * @param font
	 *            the font.
	 * @param area
	 *            the text area.
	 * @param alignment
	 *            the text alignment.
	 * @return one or several boxes containing the given part of text.
	 */
	Rectangle[] getBounds(int startIndex, int endIndex, String text, Font font, Rectangle area, int alignment);

}
