/*
 * Java
 *
 * Copyright 2015-2019 MicroEJ Corp. All rights reserved.
 * This library is provided in source code for use, modification and test, subject to license terms.
 * Any modification of the source code will break MicroEJ Corp. warranties on the whole library.
 */
package ej.wadapps.management;

import java.io.IOException;

/**
 * Holds some information about an application.
 */
public interface ApplicationMetadata {

	/**
	 * Gets the application name.
	 * 
	 * @return the application name.
	 */
	String getName();

	/**
	 * Gets the application version.
	 * 
	 * @return the application version.
	 */
	String getVersion();

	/**
	 * Gets the application description.
	 * 
	 * @return the application description.
	 */
	String getDescription();

	/**
	 * Gets the list of icons for this application.
	 * 
	 * @return the list of icons.
	 * @throws IOException
	 *             if an I/O error occurs.
	 */
	ImageInfo[] getIconsList() throws IOException;

	/**
	 * Gets the list of screenshots for this application.
	 * 
	 * @return the list of screenshots.
	 * @throws IOException
	 *             if an I/O error occurs.
	 */
	ImageInfo[] getScreenshotsList() throws IOException;

	/**
	 * Gets the list of extra metadatas for this application.
	 *
	 * @return the list of extra metadatas.
	 * @throws IOException
	 *             if an I/O error occurs.
	 */
	ExtraMetadata[] getExtraMetadatasList() throws IOException;

	/**
	 * Gets the application identifier.
	 * 
	 * @return the application identifier
	 */
	String getApplicationIdentifier();
}
