/*
 * Java
 *
 * Copyright 2019 MicroEJ Corp. All rights reserved.
 * This library is provided in source code for use, modification and test, subject to license terms.
 * Any modification of the source code will break MicroEJ Corp. warranties on the whole library.
 */
package googlecloud.iotcore;

import java.io.IOException;

/**
 * Service providing access to a GCP Device.
 */
public interface DeviceService {

	/**
	 * Sets the state of Device.
	 *
	 * @param data
	 *            application-dependent state data
	 * @throws IOException
	 *             on connection issues and errors of communication
	 */
	public void setState(byte[] data) throws IOException;

	/**
	 * Sets events.
	 *
	 * @param data
	 *            application-dependent event data
	 * @throws IOException
	 *             on connection issues and errors of communication
	 */
	public void setEvent(byte[] data) throws IOException;

	/**
	 * Sets sub-events.
	 *
	 * @param subEvent
	 *            the wanted sub-folder of events
	 * @param data
	 *            application-dependent sub-event data
	 * @throws IOException
	 *             on connection issues and errors of communication
	 */
	public void setSubEvent(String subEvent, byte[] data) throws IOException;

	/**
	 * Adds a configuration listener notified when the config of the device changes.
	 *
	 * @param listener
	 *            the right ConfigListener that will get notified
	 * @throws IOException
	 *             on subscription error to the config topic
	 */
	public void addConfigListener(ConfigListener listener) throws IOException;

	/**
	 * Removes a configuration listener.
	 *
	 * @param listener
	 *            the right ConfigListener that will get notified
	 * @throws IOException
	 *             on subscription error to the config topic
	 */
	public void removeConfigListener(ConfigListener listener) throws IOException;

}
